/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { NumericFilterCellComponent } from './numeric-filter-cell.component';
import { StringFilterCellComponent } from './string-filter-cell.component';
import { BooleanFilterCellComponent } from './boolean-filter-cell.component';
import { DateFilterCellComponent } from './date-filter-cell.component';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { CalendarDOMService, CenturyViewService, DecadeViewService, MonthViewService, YearViewService, NavigationService } from '@progress/kendo-angular-dateinputs';
import { DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { KENDO_GRID_FILTER_ROW } from '../../directives';
import * as i0 from "@angular/core";
import * as i1 from "../filter-row.component";
import * as i2 from "./filter-cell.component";
import * as i3 from "./filter-cell-template.directive";
import * as i4 from "./string-filter-cell.component";
import * as i5 from "./numeric-filter-cell.component";
import * as i6 from "./autocomplete-filter-cell.component";
import * as i7 from "./boolean-filter-cell.component";
import * as i8 from "./filter-cell-host.directive";
import * as i9 from "./filter-cell-wrapper.component";
import * as i10 from "./date-filter-cell.component";
import * as i11 from "../../columns/column.component";
import * as i12 from "../../columns/column-group.component";
import * as i13 from "../../navigation/logical-cell.directive";
import * as i14 from "../../navigation/logical-row.directive";
import * as i15 from "../../navigation/focusable.directive";
import * as i16 from "../../rendering/footer/footer-template.directive";
import * as i17 from "../../rendering/common/col-group.component";
import * as i18 from "../../layout/resizable.directive";
import * as i19 from "@progress/kendo-angular-common";
import * as i20 from "../../rendering/common/field-accessor.pipe";
import * as i21 from "../../rendering/details/detail-template.directive";
import * as i22 from "../../columns/span-column.component";
import * as i23 from "../../rendering/common/loading.component";
import * as i24 from "../../rendering/grid-table.directive";
import * as i25 from "./filter-cell-operators.component";
import * as i26 from "../operators/contains-filter-operator.component";
import * as i27 from "../operators/not-contains-filter-operator.component";
import * as i28 from "../operators/ends-with-filter-operator.component";
import * as i29 from "../operators/eq-filter-operator.component";
import * as i30 from "../operators/is-empty-filter-operator.component";
import * as i31 from "../operators/is-not-empty-filter-operator.component";
import * as i32 from "../operators/is-not-null-filter-operator.component";
import * as i33 from "../operators/isnull-filter-operator.component";
import * as i34 from "../operators/neq-filter-operator.component";
import * as i35 from "../operators/starts-with-filter-operator.component";
import * as i36 from "../operators/gt-filter-operator.component";
import * as i37 from "../operators/gte-filter-operator.component";
import * as i38 from "../operators/lt-filter-operator.component";
import * as i39 from "../operators/lte-filter-operator.component";
import * as i40 from "../operators/after-filter-operator.component";
import * as i41 from "../operators/after-eq-filter-operator.component";
import * as i42 from "../operators/before-eq-filter-operator.component";
import * as i43 from "../operators/before-filter-operator.component";
import * as i44 from "../filter-input.directive";
const ENTRY_COMPONENTS = [
    StringFilterCellComponent,
    NumericFilterCellComponent,
    BooleanFilterCellComponent,
    DateFilterCellComponent
];
/**
 * @hidden
 *
 * This module is deprecated and will be removed in a future major version release.
 */
export class RowFilterModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RowFilterModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: RowFilterModule, imports: [i1.FilterRowComponent, i2.FilterCellComponent, i3.FilterCellTemplateDirective, i4.StringFilterCellComponent, i5.NumericFilterCellComponent, i6.AutoCompleteFilterCellComponent, i7.BooleanFilterCellComponent, i8.FilterCellHostDirective, i9.FilterCellWrapperComponent, i10.DateFilterCellComponent, i11.ColumnComponent, i12.ColumnGroupComponent, i13.LogicalCellDirective, i14.LogicalRowDirective, i15.FocusableDirective, i16.FooterTemplateDirective, i17.ColGroupComponent, i18.ResizableContainerDirective, i19.TemplateContextDirective, i20.FieldAccessorPipe, i21.DetailTemplateDirective, i22.SpanColumnComponent, i23.LoadingComponent, i24.GridTableDirective, i25.FilterCellOperatorsComponent, i26.ContainsFilterOperatorComponent, i27.DoesNotContainFilterOperatorComponent, i28.EndsWithFilterOperatorComponent, i29.EqualFilterOperatorComponent, i30.IsEmptyFilterOperatorComponent, i31.IsNotEmptyFilterOperatorComponent, i32.IsNotNullFilterOperatorComponent, i33.IsNullFilterOperatorComponent, i34.NotEqualFilterOperatorComponent, i35.StartsWithFilterOperatorComponent, i36.GreaterFilterOperatorComponent, i37.GreaterOrEqualToFilterOperatorComponent, i38.LessFilterOperatorComponent, i39.LessOrEqualToFilterOperatorComponent, i40.AfterFilterOperatorComponent, i41.AfterEqFilterOperatorComponent, i42.BeforeEqFilterOperatorComponent, i43.BeforeFilterOperatorComponent, i44.FilterInputDirective], exports: [i1.FilterRowComponent, i2.FilterCellComponent, i3.FilterCellTemplateDirective, i4.StringFilterCellComponent, i5.NumericFilterCellComponent, i6.AutoCompleteFilterCellComponent, i7.BooleanFilterCellComponent, i8.FilterCellHostDirective, i9.FilterCellWrapperComponent, i10.DateFilterCellComponent, i11.ColumnComponent, i12.ColumnGroupComponent, i13.LogicalCellDirective, i14.LogicalRowDirective, i15.FocusableDirective, i16.FooterTemplateDirective, i17.ColGroupComponent, i18.ResizableContainerDirective, i19.TemplateContextDirective, i20.FieldAccessorPipe, i21.DetailTemplateDirective, i22.SpanColumnComponent, i23.LoadingComponent, i24.GridTableDirective, i25.FilterCellOperatorsComponent, i26.ContainsFilterOperatorComponent, i27.DoesNotContainFilterOperatorComponent, i28.EndsWithFilterOperatorComponent, i29.EqualFilterOperatorComponent, i30.IsEmptyFilterOperatorComponent, i31.IsNotEmptyFilterOperatorComponent, i32.IsNotNullFilterOperatorComponent, i33.IsNullFilterOperatorComponent, i34.NotEqualFilterOperatorComponent, i35.StartsWithFilterOperatorComponent, i36.GreaterFilterOperatorComponent, i37.GreaterOrEqualToFilterOperatorComponent, i38.LessFilterOperatorComponent, i39.LessOrEqualToFilterOperatorComponent, i40.AfterFilterOperatorComponent, i41.AfterEqFilterOperatorComponent, i42.BeforeEqFilterOperatorComponent, i43.BeforeFilterOperatorComponent, i44.FilterInputDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RowFilterModule, providers: [
            PopupService,
            ResizeBatchService,
            IconsService,
            DialogContainerService,
            DialogService,
            WindowService,
            WindowContainerService,
            CalendarDOMService,
            CenturyViewService,
            DecadeViewService,
            MonthViewService,
            YearViewService,
            NavigationService
        ], imports: [i4.StringFilterCellComponent, i5.NumericFilterCellComponent, i6.AutoCompleteFilterCellComponent, i7.BooleanFilterCellComponent, i9.FilterCellWrapperComponent, i10.DateFilterCellComponent, i25.FilterCellOperatorsComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RowFilterModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_GRID_FILTER_ROW],
                    imports: [...KENDO_GRID_FILTER_ROW],
                    providers: [
                        PopupService,
                        ResizeBatchService,
                        IconsService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService,
                        CalendarDOMService,
                        CenturyViewService,
                        DecadeViewService,
                        MonthViewService,
                        YearViewService,
                        NavigationService
                    ]
                }]
        }] });
